# Django DF Import Export

Helpers for [Django import / export](https://django-import-export.readthedocs.io/en/latest/)

## Installation:

- Install the package

```
pip install django-df-import-export
```

## Usage:

...

## Development

Installing dev requirements:

```
pip install -e .[test]
```

Installing pre-commit hook:

```
pre-commit install
```

Running tests:

```
pytest
```
